Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DataSource ¶
type DataSource struct {
Type string
OrderManager ordermanager.OrderManagerOptions
AccountManager accountmanager.AccountManagerOptions
MotanClient motan.MotanClientOptions
}
type GlobalConfig ¶
type GlobalConfig struct {
Title string `required:"true"`
Mysql *dao.MysqlOptions
Redis redis.RedisOptions
Accessor accessor.AccessorOptions
LoopringAccessor loopringaccessor.LoopringProtocolOptions
Miner MinerOptions
Log zap.Config
Keystore KeyStoreOptions
MarketCap marketcap.MarketCapOptions
MarketUtil marketutil.MarketOptions
ZkLock zklock.ZkLockConfig
DataSource DataSource
Kafka kafka.KafkaOptions
Sns sns.SnsConfig
}
func LoadConfig ¶
func LoadConfig(file string) *GlobalConfig
type KeyStoreOptions ¶
type MinerOptions ¶
type MinerOptions struct {
RingMaxLength int `` //recommended value:4
Subsidy float64
WalletSplit float64
NormalMiners []NormalMinerAddress //
PercentMiners []PercentMinerAddress //
TimingMatcher *TimingMatcher
RateRatioCVSThreshold int64
MinGasLimit int64
MaxGasLimit int64
FeeReceipt string
}
type NormalMinerAddress ¶
type NormalMinerAddress struct {
Address string
MaxPendingTtl int //if a tx is still pending after MaxPendingTtl blocks, the nonce used by it will be used again.
MaxPendingCount int64 //this addr will be used to send tx again until the count of pending txs belows MaxPendingCount.
GasPriceLimit int64 //the max gas price
}
type PercentMinerAddress ¶
Click to show internal directories.
Click to hide internal directories.